@@ -31,16 +31,17 @@ method.B <- function(alpha = 0.05, path.in = NULL, path.out = NULL,
     ext   <- ""
   }
   logtrans <- ret$transf
-  os <- Sys.info()[[1]] # get OS for line-endings in output (Win: CRLF)
+  os <- Sys.info()[[1]]   # get OS for line-endings in output (Win: CRLF)
   ow <- options("digits") # save options
-  options(digits=12)    # increase digits for anova()
-  if (option == 2) {    # by nlme (Residual DF)
+  options(digits=12)      # increase digits for anova()
+  on.exit(ow)             # ensure that options are reset if an error occurs
+  if (option == 2) {      # by nlme (Residual DF)
     options(contrasts=c("contr.treatment", "contr.poly"))
-    if (logtrans) {     # use the raw data and log-transform internally
+    if (logtrans) {       # use the raw data and log-transform internally
       modB <- lme(log(PK) ~ sequence + period + treatment,
                             random = ~1|subject, na.action=na.omit,
                             data=ret$data)
-    } else {            # use the already log-transformed data
+    } else {              # use the already log-transformed data
       modB <- lme(logPK ~ sequence + period + treatment,
                           random = ~1|subject, na.action=na.omit,
                           data=ret$data)
@@ -258,5 +259,4 @@ method.B <- function(alpha = 0.05, path.in = NULL, path.out = NULL,
     writeBin(charToRaw(res.str), res.file)
     close(res.file)
   }
-  on.exit(ow) # ensure that options are reset
 } # end of function method.B()
